import logo from "./logo.webp";
import DropdownMenu from "./DropdownMenu";
import OpenPageButton from "./OpenPageButton";
import { useNavigate, Outlet } from "react-router-dom";
import { useState } from "react";
import "./Header.css";
import Ender from "../Footer/Ender";

/**
 * @param {null} null -  Takes in nothing
 * @returns {JSX.Element} JSX - HTML tags and JS functionality
 * @description The top header part of the page includes the naviagtion
 * @author Brock <darkicewolf50@gmail.com>
 */
const Header = () => {
	const [isDropdownVisible, setDropdownVisible] = useState(false);
	const navigate = useNavigate();

	/**
	 * @param {String} arg -  The page that the button goes to
	 * @returns {JSX.Element} JSX - HTML tags and JS functionality
	 * @description Function that move you to the specified place
	 * @author Brock <darkicewolf50@gmail.com>
	 */
	const LinkTo = (arg) => {
		navigate(arg);
	};

	//makes the drop down menu visible when the mouse enters the Club Membership & Upcoming events button area
	const handleMouseEnter = () => {
		setDropdownVisible(true);
	};
	//makes the drop down menu invisible when the mouse leaves the Club Membership & Upcoming events button area
	const handleMouseLeave = () => {
		setDropdownVisible(false);
	};

	return (
		<>
			<header>
				<figure onClick={() => LinkTo("/")}>
					<img
						id="logo"
						src={logo}
						alt="Schulich Off-Road's logo"
					/>
					<figcaption>
						<h2>Schulich Offroad</h2>
					</figcaption>
				</figure>
				<nav>
					<OpenPageButton
						pageToGoTo={"/"}
						textOnButton={"About Us"}
					/>
					<OpenPageButton
						pageToGoTo={"/Teams"}
						textOnButton={"Teams"}
					/>
					<OpenPageButton
						pageToGoTo={"/OurSponsors"}
						textOnButton={"Our Sponsors"}
					/>
					<OpenPageButton
						pageToGoTo={"/BecomeASponsor"}
						textOnButton={"Become a Sponsor"}
					/>
					<div
						onMouseEnter={handleMouseEnter}
						onMouseLeave={handleMouseLeave}
						style={{ background: "red" }}>
						{/* dropdown menu is only visible when a mouse enters the area of the button below */}
						<button type="button">Club Membership & Upcoming Events</button>{" "}
						{/*this button does nothing yet*/}
						{isDropdownVisible && <DropdownMenu />}
					</div>
					<OpenPageButton
						pageToGoTo={"/Gallery"}
						textOnButton={"Gallery"}
					/>
				</nav>
			</header>
			<Outlet />
			<Ender />
		</>
	);
};

export default Header;
